darkhistory.spec.spectools
==========================

.. automodule:: darkhistory.spec.spectools

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: spectools
   
      discretize
      engloss_rebin_fast
      get_bin_bound
      get_bounds_between
      get_indx
      get_log_bin_width
      get_normalized_spec
      rebin_N_arr
   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree: spectools
   
      EnglossRebinData
   
   

   
   
   